@@ -3,6 +3,8 @@ import logging
 import pandas as pd
 import datetime as dt
 
+import operator
+
 class Session:
     def __init__(self, user, password, host, db='Test'):
         """ Initialize connection to database
@@ -139,4 +141,50 @@ class Session:
             *(alc.Column(column_name, self.type_dict[column_type]) for column_name, column_type in zip(columns, types)))
 
         # create table in database
-        self.meta.create_all(self.engine)
\ No newline at end of file
+        self.meta.create_all(self.engine)
+
+    def select(self, query_tables, conditions={}):
+        """ Select elements with corresponding row and column values
+
+            args:
+                tables ---- list of tables to select elements from
+
+            kwargs:
+                conditions ---- dictionary of column names and conditions.
+                                conditions are represented as a three-tuple of 
+                                table, operation and operand value.
+            
+            example: Session.select(['test'], {'id': ('test', '>', '1')})
+            
+        """
+
+        # create table objects out of table names
+        self.meta.reflect(self.engine)
+        tables = []
+        for table in query_tables:
+            tables.append(self.meta.tables[table])
+
+        # create query in specified tables
+        query = alc.sql.select(tables)
+        
+        # add condition for each column to select
+        for column in conditions:
+            query = query.where(comp_string_to_op(conditions[column][1])(self.meta.tables[conditions[column][0]].columns[column], conditions[column][2]))
+
+        # return results
+        return self.conn.execute(query).fetchall()
+
+def comp_string_to_op(string):
+    """ Converts string of expression to sqlalchemy binaryexpression
+    """
+
+    ops = {
+        '>' : operator.gt,
+        '>=' : operator.ge,
+        '<' : operator.lt,
+        '<=' : operator.le,
+        '==' : operator.eq,
+        '!=' : operator.ne
+    }
+
+    return ops[string]
\ No newline at end of file
